@@ -71,10 +71,4 @@ class ListPersonTraceDetailsRequest(RpcRequest):
 		return self.get_body_params().get('PersonId')
 
 	def set_PersonId(self,PersonId):
-		self.add_body_params('PersonId', PersonId)
-
-	def get_IsvId(self):
-		return self.get_body_params().get('IsvId')
-
-	def set_IsvId(self,IsvId):
-		self.add_body_params('IsvId', IsvId)
\ No newline at end of file
+		self.add_body_params('PersonId', PersonId)
\ No newline at end of file
